@@ -1,4 +1,4 @@
-__all__ = ['Action', 'Platform']
+__all__ = ['Action', 'ButtonsGroup', 'Platform']
 
 from enum import auto
 
@@ -10,6 +10,14 @@ class Action(FlanaEnum):
     MESSAGE_DELETED = auto()
 
 
+class ButtonsGroup(FlanaEnum):
+    CONFIG = auto()
+    POLL = auto()
+    ROLES = auto()
+    USERS = auto()
+    WEATHER = auto()
+
+
 class Platform(FlanaEnum):
     DISCORD = auto()
     TELEGRAM = auto()
